// java wrapper for vtkGPUInfoList object
//

package vtk;
import vtk.*;

public class vtkGPUInfoList extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Probe_2();
  public void Probe()
    { Probe_2(); }

  private native boolean IsProbed_3();
  public boolean IsProbed()
    { return IsProbed_3(); }

  private native int GetNumberOfGPUs_4();
  public int GetNumberOfGPUs()
    { return GetNumberOfGPUs_4(); }

  private native long GetGPUInfo_5(int id0);
  public vtkGPUInfo GetGPUInfo(int id0) {
    long temp = GetGPUInfo_5(id0);

    if (temp == 0) return null;
    return (vtkGPUInfo)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkGPUInfoList() { super(); }

  public vtkGPUInfoList(long id) { super(id); }
  public native long   VTKInit();

}
